@@ -4,8 +4,49 @@ import ssl
 import logging
 import zmq
 import uuid
+import json
+
+from .constants import *
+
 # TODO: Add documentation
 
+class MQTT(object):
+
+    """A connection only control"""
+    def get_state(self):
+        return ""
+    
+    def get_cfg(self, page_size_x, page_size_y):
+        cfg_str = "\tCFG\t" + self.msg_type + "\t" + json.dumps(self._cfg) + "\n"
+        return cfg_str
+
+    def __init__(self, control_id, username="", password="", servername="", use_ssl=False):
+        self._cfg = {}
+        self.msg_type = "MQTT"
+        self.control_id = control_id
+        self.username = username
+        self.servername = servername
+
+    def set_mqtt(self, username, servername):
+        self.username = username
+        self.servername = servername
+
+    @property
+    def username(self) -> str:
+        return self._cfg["userName"]
+
+    @username.setter
+    def username(self, val: str):
+        self._cfg["userName"] = val
+
+    @property
+    def servername(self) -> str:
+        return self._cfg["hostURL"]
+
+    @servername.setter
+    def servername(self, val: str):
+        self._cfg["hostURL"] = val
+
 
 class mqttConnection(threading.Thread):
     """Setups and manages a connection thread to the Dash Server."""
@@ -14,12 +55,12 @@ class mqttConnection(threading.Thread):
         if rc == 0:
             self.connected = True
             self.disconnect = False
-            if self.connection_topic_list:
-                for topic in self.connection_topic_list:
-                    self.dash_c.subscribe(topic, 0)
+            for device_id in self.device_id_list:
+                control_topic = "{}/{}/control".format(self.username, device_id)
+                self.dash_c.subscribe(control_topic, 0)
             logging.debug("connected OK")
         else:
-            logging.debug("Bad connection Returned code=%s",rc)
+            logging.debug("Bad connection Returned code=%s", rc)
 
     def __on_disconnect(self, client, userdata, rc):
         logging.debug("disconnecting reason  "  + str(rc))
@@ -39,14 +80,19 @@ class mqttConnection(threading.Thread):
 
     def __on_log(self, client, obj, level, string):
         logging.debug(string)
-
+    
     def add_device(self, device):
-        device.add_connection(self)
-        control_topic = "{}/{}/control".format(self.username, device.device_id)
-        self.connection_topic_list.append(control_topic)
-        if self.connected:
-            self.dash_c.subscribe(control_topic, 0)
-        device.send_dash_connect()
+        if device.device_id not in self.device_id_list:
+            self.device_id_list.append(device.device_id)
+            device._add_connection(self)
+            device.add_control(self.dash_control)
+
+            self.rx_zmq_sub.connect(DEVICE_PUB_URL.format(id=device._zmq_pub_id))
+            self.rx_zmq_sub.setsockopt_string(zmq.SUBSCRIBE, device._zmq_pub_id)
+
+            if self.connected:
+                control_topic = "{}/{}/control".format(self.username, device.device_id)
+                self.dash_c.subscribe(control_topic, 0)
 
     def __init__(self, host, port, username="", password="", use_ssl=False, context=None):
         """
@@ -66,6 +112,7 @@ class mqttConnection(threading.Thread):
 
         self.connected = False
         self.connection_topic_list = []
+        self.device_id_list = []
         self.connection_id = uuid.uuid4()
         self.b_connection_id = self.connection_id.bytes
 
@@ -104,31 +151,29 @@ class mqttConnection(threading.Thread):
     def run(self):
         self.mqttc.loop_start()
 
-        tx_url_internal = "inproc://TX_{}".format(self.connection_id.hex)
-        rx_url_internal = "inproc://RX_{}".format(self.connection_id.hex)
 
         self.tx_zmq_pub = self.context.socket(zmq.PUB)
+        self.tx_zmq_pub.bind(CONNECTION_PUB_URL.format(id=self.connection_id))
 
-        self.tx_zmq_pub.bind(tx_url_internal)
+        self.rx_zmq_sub = self.context.socket(zmq.SUB)
+        self.tx_zmq_pub = self.context.socket(zmq.PUB)
 
-        rx_zmq_sub = self.context.socket(zmq.SUB)
-        rx_zmq_sub.bind(rx_url_internal)
 
         # Subscribe on ALL, and my connection
-        rx_zmq_sub.setsockopt(zmq.SUBSCRIBE, b"ALL")
-        rx_zmq_sub.setsockopt(zmq.SUBSCRIBE, b"ALARM")
-        rx_zmq_sub.setsockopt(zmq.SUBSCRIBE, self.b_connection_id)
+        self.rx_zmq_sub.setsockopt(zmq.SUBSCRIBE, b"ALL")
+        self.rx_zmq_sub.setsockopt(zmq.SUBSCRIBE, b"ALARM")
+        self.rx_zmq_sub.setsockopt_string(zmq.SUBSCRIBE, self.connection_id)
 
         poller = zmq.Poller()
-        poller.register(rx_zmq_sub, zmq.POLLIN)
+        poller.register(self.rx_zmq_sub, zmq.POLLIN)
 
         while self.running:
             try:
                 socks = dict(poller.poll(50))
             except zmq.error.ContextTerminated:
                 break
-            if rx_zmq_sub in socks:
-                [address, id, data] = rx_zmq_sub.recv_multipart()
+            if self.rx_zmq_sub in socks:
+                [address, id, data] = self.rx_zmq_sub.recv_multipart()
                 msg_l = data.split(b'\t')
                 device_id = msg_l[1].decode('utf-8').strip()
                 if self.connected:
@@ -138,4 +183,4 @@ class mqttConnection(threading.Thread):
 
         self.mqttc.loop_stop()
         self.tx_zmq_pub.close()
-        rx_zmq_sub.close()
+        self.rx_zmq_sub.close()
